@@ -1,15 +1,22 @@
 from os import PathLike
-from typing import Annotated, Optional, Type, Union
+from typing import Optional, Type, Union
 
+from flytekit.core.annotation import FlyteAnnotation
 from flytekit.core.context_manager import FlyteContext
-# Note this only exists in flaightkit fork.
 from flytekit.core.type_engine import TypeEngine, TypeTransformer
-from flytekit.core.with_metadata import FlyteMetadata
 from flytekit.models.literals import Literal
-from flytekit.types.directory.types import (FlyteDirectory,
-                                            FlyteDirToMultipartBlobTransformer)
+from flytekit.types.directory.types import (
+    FlyteDirectory,
+    FlyteDirToMultipartBlobTransformer,
+)
+
 from latch.types.url import LatchURL
 
+try:
+    from typing import Annotated
+except ImportError:
+    from typing_extensions import Annotated
+
 
 class LatchDir(FlyteDirectory):
     """Represents a directory in the context of a task execution.
@@ -43,9 +50,12 @@ class LatchDir(FlyteDirectory):
             return LatchDir("./foo", "latch:///foo")
     """
 
-    def __init__(self, path: Union[str, PathLike], remote_path: PathLike, **kwargs):
+    def __init__(
+        self, path: Union[str, PathLike], remote_path: PathLike = None, **kwargs
+    ):
 
-        self._remote_directory = LatchURL(remote_path).url  # validates url string
+        if remote_path is not None:
+            self._remote_directory = LatchURL(remote_path).url  # validates url string
 
         if kwargs.get("downloader") is not None:
             super().__init__(path, kwargs["downloader"], remote_path)
@@ -64,17 +74,20 @@ class LatchDir(FlyteDirectory):
     @property
     def local_path(self) -> str:
         """File path local to the environment executing the task."""
-        return self._path
+        return self.path
 
     @property
     def remote_path(self) -> Optional[str]:
         """A url referencing in object in LatchData or s3."""
         return self._remote_directory
 
+    def __str__(self):
+        return f'LatchDir("{self.local_path}")'
+
 
 LatchOutputDir = Annotated[
     LatchDir,
-    FlyteMetadata(
+    FlyteAnnotation(
         {"output": True},
     ),
 ]
@@ -118,9 +131,9 @@ class LatchDirPathTransformer(FlyteDirToMultipartBlobTransformer):
         local_folder = ctx.file_access.get_random_local_directory()
 
         def _downloader():
-            return ctx.file_access.get_data(uri, local_folder, is_multipart=False)
+            return ctx.file_access.get_data(uri, local_folder, is_multipart=True)
 
         return LatchDir(local_folder, uri, downloader=_downloader)
 
 
-TypeEngine.register(LatchDirPathTransformer)
+TypeEngine.register(LatchDirPathTransformer())
